//
// gsl-lite is based on GSL: Guidelines Support Library.
// For more information see https://github.com/gsl-lite/gsl-lite
//
// Copyright (c) 2015-2018 Martin Moene
// Copyright (c) 2015-2018 Microsoft Corporation. All rights reserved.
//
// This code is licensed under the MIT License (MIT).
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

#ifndef GSL_LITE_GSL_LITE_HPP_INCLUDED
#define GSL_LITE_GSL_LITE_HPP_INCLUDED

#if ! defined( gsl_CONFIG_DEFAULTS_VERSION ) || gsl_CONFIG_DEFAULTS_VERSION == 0
# error Header <gsl-lite/gsl-lite.hpp> requires version 1 defaults; set gsl_CONFIG_DEFAULTS_VERSION=1 or link to CMake target "gsl::gsl-lite-v1"
#endif

#include <gsl/gsl-lite.hpp>

#endif // GSL_LITE_GSL_LITE_HPP_INCLUDED

// end of file
